==> wiredash-0.3.0.tar.gz: lib/src/common/translation/l10n/messages_tr.dart <==
import 'package:wiredash/wiredash.dart';

class WiredashLocalizedTranslations extends WiredashTranslations {
  const WiredashLocalizedTranslations() : super();
  @override
  String get captureSaveScreenshot => "Ekran görüntüsünü kaydet";
  @override
  String get captureSkip => "Ekran görüntüsü alma";
  @override
  String get captureSpotlightNavigateMsg =>
      "Ekran görüntüsü almak istediğiniz ekrana gidin.";
  @override
  String get captureSpotlightNavigateTitle => "ekrana git";
  @override
  String get captureSpotlightScreenCapturedMsg =>
      "Görüntü alındı! Ekran üzerinde çizim yaparak göstermek istediklerinizi işaretleyebilirisiniz.";
  @override
  String get captureSpotlightScreenCapturedTitle => "çiz";
  @override
  String get captureTakeScreenshot => "Ekran görüntüsü al";
  @override
  String get feedbackBack => "Geri";
  @override
  String get feedbackCancel => "İptal";
  @override
  String get feedbackModeBugMsg =>
      "Bizimle paylaşın ki hatayı inceleyebilelim.";
  @override
  String get feedbackModeBugTitle => "Hata Bildir";
  @override
  String get feedbackModeImprovementMsg =>
      "Uygulamamızı daha iyi yapabilecek bir fikrin mi var? Duymak isteriz!";
  @override
  String get feedbackModeImprovementTitle => "Özellik Talep Et";
  @override
  String get feedbackModePraiseMsg =>
      "Uygulamamızda en çok neyden hoşlandığını söyle, belki onu çok daha iyileştirebiliriz.";
  @override
  String get feedbackModePraiseTitle => "Övgü Yolla";
  @override
  String get feedbackSave => "Kaydet";
  @override
  String get feedbackSend => "Geri bildirim yolla";
  @override
  String get feedbackStateEmailMsg =>
      "Geri bildiriminiz hakkında güncellemeler almak istiyorsanız e-posta adresinizi aşağıya girin.";
  @override
  String get feedbackStateEmailTitle => "İletişimde kal 👇";
  @override
  String get feedbackStateFeedbackMsg =>
      "Dinliyoruz. Lütfen olabildiğince fazla bilgi verin ki size yardım edebilelim.";
  @override
  String get feedbackStateIntroMsg =>
      "Uygulamamız hakkında düşüncelerini almak için sabırsızlanıyoruz. Ne yapmak istersin?";
  @override
  String get feedbackStateIntroTitle => "Merhaba 👋";
  @override
  String get feedbackStateSuccessCloseMsg =>
      "Geri bildiriminiz için teşekkürler!";
  @override
  String get feedbackStateSuccessCloseTitle => "Bu diyalogu kapat";
  @override
  String get feedbackStateSuccessMsg =>
      "Bu kadar. Daha iyi bir uygulama yapmamıza yardım ettiğiniz için teşekkürler";
  @override
  String get feedbackStateSuccessTitle => "Teşekkürler ✌️";
  @override
  String get inputHintEmail => "E-posta adresiniz";
  @override
  String get inputHintFeedback => "Geri dönüşünüz";
  @override
  String get validationHintEmail =>
      "Lütfen geçerli bir e-posta girin yada bu alanı boş bırakın.";
  @override
  String get validationHintFeedbackEmpty => "Lütfen geri dönüşünüzü girin.";
  @override
  String get validationHintFeedbackLength => "Geri dönüşünüz çok uzun.";
  @override
  String get feedbackStateFeedbackTitle => "Geri dönüşünüz ✍️";
}

==> wiredash-0.4.0.tar.gz: lib/src/common/translation/l10n/messages_tr.dart <==
import 'package:wiredash/wiredash.dart';

class WiredashLocalizedTranslations extends WiredashTranslations {
  const WiredashLocalizedTranslations() : super();
  @override
  String get captureSaveScreenshot => "Ekran görüntüsünü kaydet";
  @override
  String get captureSkip => "Ekran görüntüsü alma";
  @override
  String get captureSpotlightNavigateMsg =>
      "Ekran görüntüsü almak istediğiniz ekrana gidin.";
  @override
  String get captureSpotlightNavigateTitle => "ekrana git";
  @override
  String get captureSpotlightScreenCapturedMsg =>
      "Görüntü alındı! Ekran üzerinde çizim yaparak göstermek istediklerinizi işaretleyebilirisiniz.";
  @override
  String get captureSpotlightScreenCapturedTitle => "çiz";
  @override
  String get captureTakeScreenshot => "Ekran görüntüsü al";
  @override
  String get feedbackBack => "Geri";
  @override
  String get feedbackCancel => "İptal";
  @override
  String get feedbackModeBugMsg =>
      "Bizimle paylaşın ki hatayı inceleyebilelim.";
  @override
  String get feedbackModeBugTitle => "Hata Bildir";
  @override
  String get feedbackModeImprovementMsg =>
      "Uygulamamızı daha iyi yapabilecek bir fikrin mi var? Duymak isteriz!";
  @override
  String get feedbackModeImprovementTitle => "Özellik Talep Et";
  @override
  String get feedbackModePraiseMsg =>
      "Uygulamamızda en çok neyden hoşlandığını söyle, belki onu çok daha iyileştirebiliriz.";
  @override
  String get feedbackModePraiseTitle => "Övgü Yolla";
  @override
  String get feedbackSave => "Kaydet";
  @override
  String get feedbackSend => "Geri bildirim yolla";
  @override
  String get feedbackStateEmailMsg =>
      "Geri bildiriminiz hakkında güncellemeler almak istiyorsanız e-posta adresinizi aşağıya girin.";
  @override
  String get feedbackStateEmailTitle => "İletişimde kal 👇";
  @override
  String get feedbackStateFeedbackMsg =>
      "Dinliyoruz. Lütfen olabildiğince fazla bilgi verin ki size yardım edebilelim.";
  @override
  String get feedbackStateIntroMsg =>
      "Uygulamamız hakkında düşüncelerini almak için sabırsızlanıyoruz. Ne yapmak istersin?";
  @override
  String get feedbackStateIntroTitle => "Merhaba 👋";
  @override
  String get feedbackStateSuccessCloseMsg =>
      "Geri bildiriminiz için teşekkürler!";
  @override
  String get feedbackStateSuccessCloseTitle => "Bu diyalogu kapat";
  @override
  String get feedbackStateSuccessMsg =>
      "Bu kadar. Daha iyi bir uygulama yapmamıza yardım ettiğiniz için çok teşekkürler!";
  @override
  String get feedbackStateSuccessTitle => "Teşekkürler ✌️";
  @override
  String get inputHintEmail => "E-posta adresiniz";
  @override
  String get inputHintFeedback => "Geri bildiriminiz";
  @override
  String get validationHintEmail =>
      "Lütfen geçerli bir e-posta girin yada bu alanı boş bırakın.";
  @override
  String get validationHintFeedbackEmpty => "Lütfen geri bildiriminiz girin.";
  @override
  String get validationHintFeedbackLength => "Geri bildiriminiz çok uzun.";
  @override
  String get feedbackStateFeedbackTitle => "Geri bildiriminiz ✍️";
  @override
  String get firstPenLabel => "";
  @override
  String get secondPenLabel => "";
  @override
  String get thirdPenLabel => "";
  @override
  String get fourthPenLabel => "";
  @override
  String get companyLogoLabel => "";
  @override
  String get undoButtonLabel => "";
  @override
  String get firstPenSelected => "";
  @override
  String get secondPenSelected => "";
  @override
  String get thirdPenSelected => "";
  @override
  String get fourthPenSelected => "";
}
